@@ -17,8 +17,6 @@ Copyright (C) 2010-2011  Lucas De Marchi <lucas.de.marchi@gmail.com>
 Copyright (C) 2011  ProFUSION embedded systems
 """
 
-from __future__ import print_function
-
 import argparse
 import codecs
 import configparser
@@ -38,7 +36,7 @@ encodings = ('utf-8', 'iso-8859-1')
 USAGE = """
 \t%prog [OPTIONS] [file1 file2 ... fileN]
 """
-VERSION = '2.1.0'
+VERSION = '2.2.1'
 
 supported_languages_en = ('en', 'en_GB', 'en_US', 'en_CA', 'en_AU')
 supported_languages = supported_languages_en
@@ -54,13 +52,13 @@ _builtin_dictionaries = (
     # realistic for obscure words
     ('clear', 'for unambiguous errors', '',
         False, None, supported_languages_en, None),
-    ('rare', 'for rare but valid words', '_rare',
+    ('rare', 'for rare (but valid) words that are likely to be errors', '_rare',  # noqa: E501
         None, None, None, None),
     ('informal', 'for making informal words more formal', '_informal',
         True, True, supported_languages_en, supported_languages_en),
     ('usage', 'for replacing phrasing with recommended terms', '_usage',
         None, None, None, None),
-    ('code', 'for words common to code and/or mathematics that might be typos', '_code',  # noqa: E501
+    ('code', 'for words from code and/or mathematics that are likely to be typos in other contexts (such as uint)', '_code',  # noqa: E501
         None, None, None, None,),
     ('names', 'for valid proper names that might be typos', '_names',
         None, None, None, None,),
@@ -293,7 +291,7 @@ def parse_options(args):
                         'The default is %(default)r.')
     parser.add_argument('--ignore-regex',
                         action='store', type=str,
-                        help='regular expression which is used to find '
+                        help='regular expression that is used to find '
                              'patterns to ignore by treating as whitespace. '
                              'When writing regular expressions, consider '
                              'ensuring there are boundary non-word chars, '
@@ -301,7 +299,7 @@ def parse_options(args):
                              'empty/disabled.')
     parser.add_argument('-I', '--ignore-words',
                         action='append', metavar='FILE',
-                        help='file that contains words which will be ignored '
+                        help='file that contains words that will be ignored '
                              'by codespell. File must contain 1 word per line.'
                              ' Words are case sensitive based on how they are '
                              'written in the dictionary file')
@@ -319,14 +317,14 @@ def parse_options(args):
                              'misspelling in URIs and emails will be ignored.')
     parser.add_argument('-r', '--regex',
                         action='store', type=str,
-                        help='regular expression which is used to find words. '
+                        help='regular expression that is used to find words. '
                              'By default any alphanumeric character, the '
                              'underscore, the hyphen, and the apostrophe is '
                              'used to build words. This option cannot be '
                              'specified together with --write-changes.')
     parser.add_argument('--uri-regex',
                         action='store', type=str,
-                        help='regular expression which is used to find URIs '
+                        help='regular expression that is used to find URIs '
                              'and emails. A default expression is provided.')
     parser.add_argument('-s', '--summary',
                         action='store_true', default=False,
@@ -345,8 +343,9 @@ def parse_options(args):
                              'you\'d give "*.eps,*.txt" to this option.')
 
     parser.add_argument('-x', '--exclude-file', type=str, metavar='FILE',
-                        help='FILE with lines that should not be checked for '
-                             'errors or changed')
+                        help='ignore whole lines that match those '
+                             'in the file FILE. The lines in FILE '
+                             'should match the to-be-excluded lines exactly')
 
     parser.add_argument('-i', '--interactive',
                         action='store', type=int, default=0,
@@ -754,7 +753,7 @@ def main(*args):
 
     if options.regex and options.write_changes:
         print("ERROR: --write-changes cannot be used together with "
-              "--regex")
+              "--regex", file=sys.stderr)
         parser.print_help()
         return EX_USAGE
     word_regex = options.regex or word_regex_def
@@ -842,7 +841,8 @@ def main(*args):
         if (options.before_context is not None) or \
                 (options.after_context is not None):
             print("ERROR: --context/-C cannot be used together with "
-                  "--context-before/-B or --context-after/-A")
+                  "--context-before/-B or --context-after/-A",
+                  file=sys.stderr)
             parser.print_help()
             return EX_USAGE
         context_both = max(0, options.context)
